/*
 * Copyright 2024 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.keycloak.models.cache.infinispan.authorization.events;

import java.util.Objects;

import org.infinispan.protostream.annotations.ProtoField;
import org.keycloak.models.cache.infinispan.events.InvalidationEvent;

abstract class BasePermissionTicketEvent extends InvalidationEvent implements AuthorizationCacheInvalidationEvent {

    private final String owner;
    private final String resource;
    private final String scope;
    private final String serverId;
    private final String requester;
    private final String resourceName;

    BasePermissionTicketEvent(String id, String owner, String resource, String scope, String serverId, String requester, String resourceName) {
        super(id);
        this.owner = owner;
        this.resource = resource;
        this.scope = scope;
        this.serverId = serverId;
        this.requester = requester;
        this.resourceName = resourceName;
    }

    @ProtoField(2)
    public String getOwner() {
        return owner;
    }

    @ProtoField(3)
    public String getRequester() {
        return requester;
    }

    @ProtoField(4)
    public String getResource() {
        return resource;
    }

    @ProtoField(5)
    public String getResourceName() {
        return resourceName;
    }

    @ProtoField(6)
    public String getScope() {
        return scope;
    }

    @ProtoField(7)
    public String getServerId() {
        return serverId;
    }

    @Override
    public String toString() {
        return "%s [ id=%s, name=%s]".formatted(getClass().getName(), getId(), resource);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        BasePermissionTicketEvent that = (BasePermissionTicketEvent) o;
        return Objects.equals(resource, that.resource) && Objects.equals(serverId, that.serverId);
    }

    @Override
    public int hashCode() {
        return Objects.hash(super.hashCode(), resource, serverId);
    }

}
